@@ -12,19 +12,21 @@
 # from examples.llamaindex_example.basic import basic
 # from examples.langchain_example.basic import basic
 # from examples.cohere_example.chat import chat_comp
-from examples.cohere_example.embed_create import embed_create
+# from examples.cohere_example.embed_create import embed_create
+from examples.hiveagent_example.basic import basic
+
 # from examples.cohere_example.chat_stream import chat_stream
 
 # from examples.perplexity_example.basic import basic
 
 # load_and_split()
 # rag()
-# basic()
+basic()
 # chat_completion()
 # function_calling()
 # images_generate()
 # embeddings_create()
 # messages_create()
 # chat_comp()
-embed_create()
+# embed_create()
 # chat_stream()
